@@ -1,8 +1,10 @@
 var namespace_oracle_extensions =
 [
-    [ "OracleDatasourceBase", "class_oracle_extensions_1_1_oracle_datasource_base.html", "class_oracle_extensions_1_1_oracle_datasource_base" ],
     [ "OracleApplicationInfo", "class_oracle_extensions_1_1_oracle_application_info.html", "class_oracle_extensions_1_1_oracle_application_info" ],
-    [ "OracleLongOps", "class_oracle_extensions_1_1_oracle_long_ops.html", "class_oracle_extensions_1_1_oracle_long_ops" ],
+    [ "OracleDatasource", "class_oracle_extensions_1_1_oracle_datasource.html", "class_oracle_extensions_1_1_oracle_datasource" ],
+    [ "OracleDatasourceBase", "class_oracle_extensions_1_1_oracle_datasource_base.html", "class_oracle_extensions_1_1_oracle_datasource_base" ],
     [ "OracleDatasourcePool", "class_oracle_extensions_1_1_oracle_datasource_pool.html", "class_oracle_extensions_1_1_oracle_datasource_pool" ],
-    [ "OracleDatasource", "class_oracle_extensions_1_1_oracle_datasource.html", "class_oracle_extensions_1_1_oracle_datasource" ]
+    [ "OracleInstrumentationBase", "class_oracle_extensions_1_1_oracle_instrumentation_base.html", "class_oracle_extensions_1_1_oracle_instrumentation_base" ],
+    [ "OracleLongOps", "class_oracle_extensions_1_1_oracle_long_ops.html", "class_oracle_extensions_1_1_oracle_long_ops" ],
+    [ "OracleSQLStatement", "class_oracle_extensions_1_1_oracle_s_q_l_statement.html", "class_oracle_extensions_1_1_oracle_s_q_l_statement" ]
 ];
\ No newline at end of file
