@@ -173,6 +173,7 @@ static const mtext * OCILib_OraFeatures[] =
     MT("Oracle 10g R2 remote database startup/shutdown")
 };
 
+/*
 static const mtext * OCILib_StmtStates[] =
 {
     MT("closed"),
@@ -187,7 +188,7 @@ static const mtext * OCILib_DirPathStates[] =
     MT("converted"),
     MT("terminated")
 };
-
+*/
 
 static const mtext * OCILib_HandleNames[] =
 {
@@ -291,7 +292,7 @@ void OCI_ExceptionNotInitialized(void)
 }
 */
 
-void OCI_ExceptionNotInitialized2(OCI_Library *pOCILib)
+void OCI_ExceptionNotInitialized2(OCI_Library *pOCILib, ExceptionSink* xsink)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
 
@@ -304,7 +305,7 @@ void OCI_ExceptionNotInitialized2(OCI_Library *pOCILib)
                 msizeof(err->str) - (size_t) 1);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 }
 
 /* ------------------------------------------------------------------------ *
@@ -317,7 +318,8 @@ void OCI_ExceptionLoadingSharedLib(void)
 }
 */
 
-void OCI_ExceptionLoadingSharedLib2(OCI_Library *pOCILib)
+/*
+void OCI_ExceptionLoadingSharedLib2(OCI_Library *pOCILib, ExceptionSink* xsink)
 {
 #ifdef OCI_IMPORT_RUNTIME
 
@@ -333,10 +335,11 @@ void OCI_ExceptionLoadingSharedLib2(OCI_Library *pOCILib)
                   OCI_DL_META_NAME);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 
 #endif
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionLoadingSymbols
@@ -348,6 +351,7 @@ void OCI_ExceptionLoadingSymbols(void)
 }
 */
 
+/*
 void OCI_ExceptionLoadingSymbols2(OCI_Library *pOCILib)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -361,7 +365,9 @@ void OCI_ExceptionLoadingSymbols2(OCI_Library *pOCILib)
                 msizeof(err->str) - (size_t) 1);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);}
+    OCI_ExceptionRaise2(pOCILib, err);
+}
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionNotMultithreaded
@@ -373,6 +379,7 @@ void OCI_ExceptionNotMultithreaded(void)
 }
 */
 
+/*
 void OCI_ExceptionNotMultithreaded2(OCI_Library *pOCILib)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -388,12 +395,13 @@ void OCI_ExceptionNotMultithreaded2(OCI_Library *pOCILib)
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionNullPointer
  * ------------------------------------------------------------------------ */
 
-void OCI_ExceptionNullPointer2(OCI_Library *pOCILib, int type)
+void OCI_ExceptionNullPointer2(OCI_Library *pOCILib, int type, ExceptionSink* xsink)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
 
@@ -407,13 +415,14 @@ void OCI_ExceptionNullPointer2(OCI_Library *pOCILib, int type)
                   OCILib_TypeNames[type-1]);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 }
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionMemory
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionMemory2(OCI_Library *pOCILib, int type, size_t nb_bytes, OCI_Connection *con,
 			  OCI_Statement *stmt)
 {
@@ -435,12 +444,13 @@ void OCI_ExceptionMemory2(OCI_Library *pOCILib, int type, size_t nb_bytes, OCI_C
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionNotAvailable
  * ------------------------------------------------------------------------ */
 
-void OCI_ExceptionNotAvailable2(OCI_Library *pOCILib, OCI_Connection *con, int feature)
+void OCI_ExceptionNotAvailable2(OCI_Library *pOCILib, OCI_Connection *con, int feature, ExceptionSink* xsink)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
 
@@ -456,13 +466,14 @@ void OCI_ExceptionNotAvailable2(OCI_Library *pOCILib, OCI_Connection *con, int f
                   OCILib_OraFeatures[feature-1]);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 }
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionDatatypeNotSupported
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionDatatypeNotSupported2(OCI_Library *pOCILib, OCI_Connection *con, OCI_Statement *stmt,
 					int code)
 {
@@ -483,11 +494,13 @@ void OCI_ExceptionDatatypeNotSupported2(OCI_Library *pOCILib, OCI_Connection *co
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionParsingError
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionParsingToken2(OCI_Library *pOCILib, OCI_Connection *con, OCI_Statement *stmt, mtext token)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -507,11 +520,13 @@ void OCI_ExceptionParsingToken2(OCI_Library *pOCILib, OCI_Connection *con, OCI_S
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionMappingArgument
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionMappingArgument2(OCI_Library *pOCILib, OCI_Connection *con, OCI_Statement *stmt,
 				   int arg)
 {
@@ -532,12 +547,13 @@ void OCI_ExceptionMappingArgument2(OCI_Library *pOCILib, OCI_Connection *con, OC
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionOutOfBounds
  * ------------------------------------------------------------------------ */
 
-void OCI_ExceptionOutOfBounds2(OCI_Library *pOCILib, OCI_Connection *con, int value)
+void OCI_ExceptionOutOfBounds2(OCI_Library *pOCILib, OCI_Connection *con, int value, ExceptionSink* xsink)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
 
@@ -553,14 +569,14 @@ void OCI_ExceptionOutOfBounds2(OCI_Library *pOCILib, OCI_Connection *con, int va
                   value);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 }
 
  /* ------------------------------------------------------------------------ *
  * OCI_ExceptionUnfreedData
  * ------------------------------------------------------------------------ */
 
-void  OCI_ExceptionUnfreedData2(OCI_Library *pOCILib, int type_elem, int nb_elem)
+void  OCI_ExceptionUnfreedData2(OCI_Library *pOCILib, int type_elem, int nb_elem, ExceptionSink* xsink)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
 
@@ -575,13 +591,14 @@ void  OCI_ExceptionUnfreedData2(OCI_Library *pOCILib, int type_elem, int nb_elem
                   nb_elem, OCILib_HandleNames[type_elem-1]);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 }
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionRuntimeLoading
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionMaxBind2(OCI_Library *pOCILib, OCI_Statement *stmt)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -604,6 +621,7 @@ void OCI_ExceptionMaxBind2(OCI_Library *pOCILib, OCI_Statement *stmt)
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionAttributeNotFound
@@ -632,7 +650,7 @@ void OCI_ExceptionAttributeNotFound2(OCI_Library *pOCILib, OCI_Connection *con,
  * OCI_ExceptionMinimumValue
  * ------------------------------------------------------------------------ */
 
-void OCI_ExceptionMinimumValue2(OCI_Library *pOCILib, OCI_Connection *con, OCI_Statement *stmt, int min)
+void OCI_ExceptionMinimumValue2(OCI_Library *pOCILib, OCI_Connection *con, OCI_Statement *stmt, int min, ExceptionSink* xsink)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
 
@@ -646,14 +664,14 @@ void OCI_ExceptionMinimumValue2(OCI_Library *pOCILib, OCI_Connection *con, OCI_S
                   OCILib_ErrorMsg[OCI_ERR_MIN_VALUE], min);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 }
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionTypeNotCompatible
  * ------------------------------------------------------------------------ */
 
-void OCI_ExceptionTypeNotCompatible2(OCI_Library *pOCILib, OCI_Connection *con)
+void OCI_ExceptionTypeNotCompatible2(OCI_Library *pOCILib, OCI_Connection *con, ExceptionSink* xsink)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
 
@@ -667,13 +685,14 @@ void OCI_ExceptionTypeNotCompatible2(OCI_Library *pOCILib, OCI_Connection *con)
                 msizeof(err->str) - (size_t) 1);
     }
 
-    OCI_ExceptionRaise2(pOCILib, err);
+    OCI_ExceptionRaise2(pOCILib, err, xsink);
 }
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionStatementState
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionStatementState2(OCI_Library *pOCILib, OCI_Statement *stmt, int state)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -695,11 +714,13 @@ void OCI_ExceptionStatementState2(OCI_Library *pOCILib, OCI_Statement *stmt, int
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionStatementNotScrollable
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionStatementNotScrollable2(OCI_Library *pOCILib, OCI_Statement *stmt)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -720,11 +741,13 @@ void OCI_ExceptionStatementNotScrollable2(OCI_Library *pOCILib, OCI_Statement *s
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionBindAlreadyUsed
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionBindAlreadyUsed2(OCI_Library *pOCILib, OCI_Statement *stmt, const mtext * bind)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -746,11 +769,13 @@ void OCI_ExceptionBindAlreadyUsed2(OCI_Library *pOCILib, OCI_Statement *stmt, co
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionBindArraySize
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionBindArraySize2(OCI_Library *pOCILib, OCI_Statement *stmt, unsigned int maxsize, 
 				 unsigned int cursize, unsigned int newsize)
 {
@@ -773,11 +798,13 @@ void OCI_ExceptionBindArraySize2(OCI_Library *pOCILib, OCI_Statement *stmt, unsi
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionDirPathColNotFound
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionDirPathColNotFound2(OCI_Library *pOCILib, OCI_DirPath *dp, const mtext * column,
                                      const mtext *table)
 {
@@ -801,11 +828,12 @@ void OCI_ExceptionDirPathColNotFound2(OCI_Library *pOCILib, OCI_DirPath *dp, con
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
+*/
 
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionDirPathState
  * ------------------------------------------------------------------------ */
-
+/*
 void OCI_ExceptionDirPathState2(OCI_Library *pOCILib, OCI_DirPath *dp, int state)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -827,11 +855,12 @@ void OCI_ExceptionDirPathState2(OCI_Library *pOCILib, OCI_DirPath *dp, int state
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
-
+*/
 /* ------------------------------------------------------------------------ *
  * OCI_ExceptionOCIEnvironment
  * ------------------------------------------------------------------------ */
 
+/*
 void OCI_ExceptionOCIEnvironment2(OCI_Library *pOCILib)
 {
     OCI_Error *err = OCI_ExceptionGetError(pOCILib, FALSE);
@@ -847,4 +876,4 @@ void OCI_ExceptionOCIEnvironment2(OCI_Library *pOCILib)
 
     OCI_ExceptionRaise2(pOCILib, err);
 }
-
+*/
